@@ -45,6 +45,7 @@ public:
     void loadData(GBytes*);
     void runJavascript(const gchar*);
     void setDrawBackground(gboolean);
+    void clearBuffers();
 
     GstEGLImage* image();
     GstBuffer* buffer();
@@ -59,6 +60,10 @@ public:
     void disconnectLoadFailedSignal();
     void waitLoadCompletion();
 
+    GstWpeVideoSrc *src() const { return m_src; }
+
+    void notifyLoadFinished();
+
 protected:
     void handleExportedImage(gpointer);
     void handleExportedBuffer(struct wpe_fdo_shm_exported_buffer*);
@@ -67,7 +72,6 @@ private:
     struct wpe_view_backend* backend() const;
     void frameComplete();
     void loadUriUnlocked(const gchar*);
-    void notifyLoadFinished();
 
     void releaseImage(gpointer);
     void releaseSHMBuffer(gpointer);
@@ -121,6 +125,7 @@ private:
         gulong extension_msg_sigid;
     } audio {0, 0};
 
+    GstWpeVideoSrc *m_src { nullptr };
 };
 
 class GstWPEContextThread {
